﻿using System;
using System.Windows.Controls;
using System.Windows.Media;

using System.IO;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.Model;

namespace ExportGridToPDFDemo
{
    
    public class RadGridViewPDFExport
    {

        #region Export

        public static RadDocument Export(RadGridView Grid)
        {
            
            GridViewExportOptions exportOptions = null;
            RadDocument retVal = null;
            Table table = null;
            StreamReader streamReader = null;
            Int32 lineCounter = 0;

            #region Export to CSV Format

            // Initialize Class
            exportOptions = new GridViewExportOptions();
            // Assign Values
            exportOptions.Format = ExportFormat.Csv;
            exportOptions.Items = Grid.Items;
            exportOptions.ShowColumnFooters = false;
            exportOptions.ShowColumnHeaders = true;
            exportOptions.ShowGroupFooters = false;

            // Initialize Class
            var memoryStream = new MemoryStream();
            // Export
            Grid.Export(memoryStream,
                exportOptions);
            // Reset Position
            memoryStream.Position = 0;
            // Initialize Class
            streamReader = new StreamReader(memoryStream);

            #endregion

            #region Process CSV Data

            // Search through Lines
            while (!streamReader.Peek().Equals(-1))
            {

                // Assign Value
                string line = streamReader.ReadLine();
                // Assign Value
                string[] parameters = line.Split(new char[] { ',' });
                // Remove "
                for (int i = 0; i < parameters.Length; i++)
                {

                    // Assign Values
                    parameters[i] = parameters[i].Remove(0, 1);
                    parameters[i] = parameters[i].Remove(parameters[i].Length - 1, 1);

                }

                // Check Value
                switch (lineCounter)
                {

                    // Header Row
                    case 0:

                        TableCell headerCell = null;

                        #region Setup Table / Document Sections

                        // Initialize Class
                        retVal = new RadDocument();
                        // Initialize Class
                        table = new Table(1,
                            parameters.Length);
                        // Add Section
                        retVal.Sections.Add(new Section());
                        // Add Table
                        retVal.Sections.First.Blocks.Add(table);

                        #endregion

                        #region Add Header

                        // Search through Parameters
                        foreach (string parameter in parameters)
                        {

                            // Check Value
                            if (headerCell == null)
                            {

                                // Initialize Class
                                headerCell = table.Rows.First.Cells.First;

                            }
                            else
                            {

                                // Initialize Class
                                headerCell = (TableCell)headerCell.NextSibling;

                            }
                            // Initialize Class
                            var paragraph = new Paragraph();
                            // Set Alignment
                            paragraph.TextAlignment = Telerik.Windows.Documents.Layout.RadTextAlignment.Left;
                            // Add Paragraph
                            headerCell.Blocks.Add(paragraph);
                            // Set Colour
                            headerCell.Background = Colors.White;
                            // Initialize Class
                            var span = new Span();
                            // Assign Values
                            span.Text = parameter.Trim().Equals("") ? " " : parameter;
                            span.ForeColor = Colors.Black;
                            // Add Span
                            paragraph.Inlines.Add(span);

                        }

                        #endregion

                        break;

                    // Data Rows
                    default:

                        #region Add Row

                        Int32 cellCounter = 0;

                        // Initialize Class
                        TableRow row = table.AddRow();
                        // Search through Parameters
                        foreach (TableCell cell in row.Cells)
                        {

                            // Initialize Class
                            var paragraph = new Paragraph();
                            // Set Alignment
                            paragraph.TextAlignment = Telerik.Windows.Documents.Layout.RadTextAlignment.Left;
                            // Add Paragraph
                            cell.Blocks.Add(paragraph);
                            // Set Colour
                            cell.Background = Colors.White;
                            // Initialize Class
                            var span = new Span();
                            // Assign Values
                            span.Text = parameters[cellCounter].Trim().Equals("") ? " " : parameters[cellCounter];
                            span.ForeColor = Colors.Black;
                            // Add Span
                            paragraph.Inlines.Add(span);

                            // Increment Counter
                            cellCounter++;

                        }

                        #endregion

                        break;

                }

                // Increment Counter
                lineCounter++;

            }

            #endregion

            #region Generate PDF

            // Assign Values
            retVal.LayoutMode = DocumentLayoutMode.Paged;
            retVal.Measure(RadDocument.MAX_DOCUMENT_SIZE);
            retVal.Arrange(new RectangleF(PointF.Empty, retVal.DesiredSize));

            #endregion

            // Return
            return retVal;

        }

        #endregion

    }

}
